import { Component, ViewEncapsulation, Input, HostBinding, ElementRef, Renderer2, ɵɵdefineInjectable, Injectable, HostListener, EventEmitter, Output, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

class CellComponent {
    constructor() {
        this.alignActive = '';
        this.alignBreaks = [];
    }
    ngOnInit() {
        this.setAlignBreaks();
        this.setAlignActive();
        this.applyAlign();
    }
    setAlignBreaks() {
        if (!this.alignValue)
            return;
        const pairs = this.alignValue.split(' ');
        let pairSplit;
        this.alignBreaks = pairs.map(pair => {
            if (pair.match(/:/)) {
                pairSplit = pair.split(':');
                pairSplit[0] = isNaN(+pairSplit[0]) ? 0 : +pairSplit[0];
                return [pairSplit[0], pairSplit[1]];
            }
            return [0, pair];
        });
        this.alignBreaks = this.alignBreaks.sort((a, b) => a[0] > b[0] ? 1 : -1);
    }
    setAlignActive() {
        if (!this.alignValue) {
            return;
        }
        for (const pair of this.alignBreaks) {
            if (window.innerWidth < pair[0]) {
                break;
            }
            this.alignActive = pair[1];
        }
    }
    applyAlign() {
        switch (this.alignActive) {
            case 't':
            case 'top':
                this.alignSelf = 'flex-start';
                break;
            case 'm':
            case 'middle':
                this.alignSelf = 'center';
                break;
            case 'b':
            case 'bottom':
                this.alignSelf = 'flex-end';
                break;
        }
    }
}
CellComponent.decorators = [
    { type: Component, args: [{
                encapsulation: ViewEncapsulation.None,
                selector: 'cell',
                template: "<ng-content></ng-content>\r\n",
                styles: ["cell{box-sizing:border-box;overflow:auto;position:relative;text-align:inherit}"]
            },] }
];
CellComponent.ctorParameters = () => [];
CellComponent.propDecorators = {
    alignValue: [{ type: Input, args: ['align',] }],
    height: [{ type: Input }],
    width: [{ type: Input }],
    align: [{ type: HostBinding, args: ['style.align',] }],
    alignSelf: [{ type: HostBinding, args: ['style.alignSelf',] }]
};

class DataTableComponent {
    constructor() {
        this.tHeadRows = [];
        this.tBodyRows = [];
        this.tFootRows = [];
    }
    ngOnInit() { }
}
DataTableComponent.decorators = [
    { type: Component, args: [{
                encapsulation: ViewEncapsulation.None,
                selector: 'data-table',
                template: "<thead *ngIf=\"tHeadRows.length\">\r\n    <tr *ngFor=\"let row of tHeadRows\">\r\n        <th *ngFor=\"let cell of row\"\r\n            [attr.colspan]=\"cell.colspan\"\r\n            [attr.rowspan]=\"cell.rowspan\"\r\n            [ngClass]=\"cell.class\"\r\n        >{{ cell.value }}</th>\r\n    </tr>\r\n</thead>\r\n<tbody *ngIf=\"tBodyRows.length\">\r\n    <tr *ngFor=\"let row of tBodyRows\">\r\n        <td *ngFor=\"let cell of row\"\r\n            [attr.colspan]=\"cell.colspan\"\r\n            [attr.rowspan]=\"cell.rowspan\"\r\n            [ngClass]=\"cell.class\"\r\n        >{{ cell.value }}</td>\r\n    </tr>\r\n</tbody>\r\n<tfoot *ngIf=\"tFootRows.length\">\r\n    <tr *ngFor=\"let row of tFootRows\">\r\n        <th *ngFor=\"let cell of row\"\r\n            [attr.colspan]=\"cell.colspan\"\r\n            [attr.rowspan]=\"cell.rowspan\"\r\n            [ngClass]=\"cell.class\"\r\n        >{{ cell.value }}</th>\r\n    </tr>\r\n</tfoot>\r\n",
                styles: ["data-table{border-collapse:collapse;display:table;min-width:100%}data-table thead tr:first-of-type th{border-top:none}data-table thead th{background:#2294d3;border:1px solid #d3d3d3;color:#fff;height:30px;padding:10px;position:-webkit-sticky;position:sticky;top:0}data-table tbody td{border:1px solid #d3d3d3;padding:10px;text-align:center}data-table tfoot th{background:#2294d3;border:1px solid #d3d3d3;color:#fff;height:30px;padding:10px}"]
            },] }
];
DataTableComponent.ctorParameters = () => [];
DataTableComponent.propDecorators = {
    tHeadRows: [{ type: Input, args: ['thead-rows',] }],
    tBodyRows: [{ type: Input, args: ['tbody-rows',] }],
    tFootRows: [{ type: Input, args: ['tfoot-rows',] }]
};

class FlexButtonsComponent {
    constructor(element, renderer) {
        this.element = element;
        this.renderer = renderer;
    }
    ngAfterViewInit() {
        this.applySpace();
    }
    applySpace() {
        if (this.space) {
            for (const child of this.element.nativeElement.children) {
                this.renderer.setStyle(child, 'margin', this.space);
            }
        }
    }
}
FlexButtonsComponent.decorators = [
    { type: Component, args: [{
                encapsulation: ViewEncapsulation.None,
                selector: 'flex-buttons',
                template: "<ng-content></ng-content>\r\n",
                styles: ["flex-buttons{bottom:0;display:flex;left:0;padding:1em;position:absolute;right:0;top:0}flex-buttons button{flex-basis:100%;flex-grow:1;margin:5px}"]
            },] }
];
FlexButtonsComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 }
];
FlexButtonsComponent.propDecorators = {
    space: [{ type: Input }]
};

const DEFAULT_DENOMINATOR = 12;
class GridService {
    constructor() {
        this.heightDenom = DEFAULT_DENOMINATOR;
        this.widthDenom = DEFAULT_DENOMINATOR;
    }
    initCells(cellElements, heightDenom, heightScale, widthDenom) {
        this.heightDenom = heightDenom ? +heightDenom : DEFAULT_DENOMINATOR;
        this.heightScale = heightScale;
        this.widthDenom = widthDenom ? +widthDenom : DEFAULT_DENOMINATOR;
        this.cellElements = Array.from(cellElements) || [];
        this.readHeightScales();
        this.readCellProps();
        this.readBreaks();
        this.updateView();
    }
    readHeightScales() {
        if (!this.heightScale) {
            this.heightScaleCurrent = 1;
            return;
        }
        this.heightScale = this.trim(this.heightScale);
        this.breakHeightScales = this.splitBreaks(this.heightScale);
        this.breakHeightScales = this.breakHeightScales.sort((a, b) => a[0] > b[0] ? 1 : -1);
    }
    getCurrentHeightScaleBreak() {
        if (!this.heightScale) {
            this.heightScaleCurrent = 1;
            return;
        }
        let heightScale = 1;
        for (const pair of this.breakHeightScales) {
            if (window.innerHeight >= pair[0]) {
                heightScale = +pair[1];
            }
            else {
                break;
            }
        }
        this.heightScaleCurrent = heightScale;
    }
    readCellProps() {
        let strippedHeight;
        let strippedWidth;
        this.cellPropValues = [];
        this.cellElements.forEach(cell => {
            strippedHeight = cell.attributes['height'] ? cell.attributes['height'].value : '';
            strippedWidth = cell.attributes['width'] ? cell.attributes['width'].value : '';
            this.cellPropValues.push({
                height: this.trim(strippedHeight),
                width: this.trim(strippedWidth)
            });
        });
    }
    trim(value) {
        while (value.match(/\s\s/)) {
            value = value.replace(/\s\s/, ' ');
        }
        value = value.replace(/^\s/, '');
        value = value.replace(/\s$/, '');
        return value;
    }
    readBreaks() {
        this.breaks = [];
        this.cellPropValues.forEach(({ height, width }) => {
            this.breakHeights = [];
            this.breakWidths = [[0, this.widthDenom]];
            if (height) {
                this.breakHeights = this.splitBreaks(height);
                this.breakHeights = this.breakHeights
                    .sort((a, b) => a[0] > b[0] ? 1 : -1);
            }
            if (width) {
                this.breakWidths = this.splitBreaks(width);
                this.breakWidths = this.breakWidths
                    .sort((a, b) => a[0] > b[0] ? 1 : -1);
            }
            this.breaks.push({
                heights: this.breakHeights,
                widths: this.breakWidths
            });
        });
    }
    splitBreaks(value) {
        const pairs = value.split(' ');
        let pairSplit;
        return pairs.map(pair => {
            if (pair.match(/:/)) {
                pairSplit = pair.split(':');
                pairSplit[0] = isNaN(+pairSplit[0]) ? 0 : +pairSplit[0];
                pairSplit[1] = !pairSplit[1] ? 0 : pairSplit[1];
                return [pairSplit[0], pairSplit[1]];
            }
            return [0, pair];
        });
    }
    updateView() {
        this.getCurrentBreakValues();
        this.getCurrentHeightScaleBreak();
        this.setCalcValues();
        this.applyStyles();
    }
    getCurrentBreakValues() {
        let endRow;
        let rowFixedRunner = 0;
        let rowFlexRunner = 0;
        let rowIndex = 0;
        this.cellRowIndexes = [];
        this.currentCellValues = [];
        this.rowFixedTotals = [];
        if (this.breaks) {
            this.breaks.forEach((cell, index) => {
                let height = this.processPairHeights(cell);
                let width = this.processPairWidths(cell);
                if (height && !height.match(/px/) && !height.match(/%/) && !height.match(/\//)) {
                    height = (+height / this.heightDenom * 100) + '%';
                }
                if (width.match(/!/)) {
                    endRow = true;
                    width = width.replace('!', '');
                }
                if (width.match(/px/)) {
                    rowFixedRunner += +width.replace('px', '');
                }
                else {
                    if (rowFlexRunner === 1) {
                        this.rowFixedTotals.push(rowFixedRunner);
                        rowIndex++;
                        rowFlexRunner = 0;
                        rowFixedRunner = 0;
                    }
                    rowFlexRunner += +width / this.widthDenom;
                    width = (+width / this.widthDenom * 100) + '%';
                }
                this.cellRowIndexes[index] = rowIndex;
                if (endRow) {
                    this.rowFixedTotals.push(rowFixedRunner);
                    rowIndex++;
                    endRow = false;
                    rowFlexRunner = 0;
                    rowFixedRunner = 0;
                }
                this.currentCellValues.push({ height, width });
            });
        }
        this.rowFixedTotals.push(rowFixedRunner);
    }
    processPairHeights(cell) {
        const windowWidth = window.innerWidth;
        let height = '';
        for (const pair of cell.heights) {
            if (windowWidth >= pair[0]) {
                height = pair[1];
            }
            else {
                break;
            }
        }
        return height.toString();
    }
    processPairWidths(cell) {
        const windowWidth = window.innerWidth;
        let width = DEFAULT_DENOMINATOR;
        for (const pair of cell.widths) {
            if (windowWidth >= pair[0]) {
                width = pair[1];
            }
            else {
                break;
            }
        }
        return width.toString();
    }
    setCalcValues() {
        this.cellStyles = [];
        this.currentCellValues.forEach(({ height, width }, index) => {
            if (!width.match('px')) {
                const decimal = 0.01 * +width.replace('%', '');
                width = `calc((100% - ${this.rowFixedTotals[this.cellRowIndexes[index]]}px) * ${decimal})`;
            }
            this.cellStyles.push({ height, width });
        });
    }
    applyStyles() {
        this.cellStyles.forEach(({ height, width }, index) => {
            this.setHeightStyle(height, index, width);
            this.cellElements[index].style.width = width;
        });
    }
    setHeightStyle(height, index, width) {
        if (height.match('/')) {
            this.setHeightRatioStyles(height, index, width);
            return;
        }
        const pair = height.split('-');
        if (+pair[0]) {
            pair[0] = ((+pair[0] / this.heightDenom) * 100 * this.heightScaleCurrent) + 'vh';
        }
        else if (pair[0].match('%')) {
            const mainHeight = pair[0].split('%')[0];
            const heightWithScale = +mainHeight * this.heightScaleCurrent;
            pair[0] = heightWithScale + 'vh';
        }
        height = height.match('-') ? `calc(${pair[0]} - ${pair[1]})` : pair[0];
        this.cellElements[index].style.height = height;
    }
    setHeightRatioStyles(height, index, width) {
        let percentage = width.split('* ')[1];
        percentage = percentage.split(')')[0];
        const fraction = height.split('/');
        // no height scaling for ratios because ratio would break
        const ratio = ((+fraction[1] / +fraction[0]) * (100 * +percentage)) + '%';
        this.cellElements[index].style.height = '0';
        this.cellElements[index].style.paddingTop = ratio;
    }
}
GridService.ɵprov = ɵɵdefineInjectable({ factory: function GridService_Factory() { return new GridService(); }, token: GridService, providedIn: "root" });
GridService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
GridService.ctorParameters = () => [];

class GridComponent {
    constructor(element, gridService) {
        this.element = element;
        this.gridService = gridService;
    }
    onResize() {
        this.gridService.updateView();
    }
    ngOnInit() { }
    ngOnChanges() {
        setTimeout(() => {
            this.gridService.initCells(this.element.nativeElement.children, this.heightDenom, this.heightScale, this.widthDenom);
        }, 0);
    }
    ngAfterViewInit() {
        this.gridService.initCells(this.element.nativeElement.children, this.heightDenom, this.heightScale, this.widthDenom);
    }
}
GridComponent.decorators = [
    { type: Component, args: [{
                encapsulation: ViewEncapsulation.None,
                providers: [GridService],
                selector: 'grid',
                template: "<ng-content></ng-content>\r\n",
                styles: ["grid{display:flex;flex-wrap:wrap;position:relative}"]
            },] }
];
GridComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: GridService }
];
GridComponent.propDecorators = {
    heightDenom: [{ type: Input, args: ['height-denom',] }],
    heightScale: [{ type: Input, args: ['height-scale',] }],
    update: [{ type: Input }],
    widthDenom: [{ type: Input, args: ['width-denom',] }],
    onResize: [{ type: HostListener, args: ['window:resize', [],] }]
};

class MetricComponent {
    constructor() { }
}
MetricComponent.decorators = [
    { type: Component, args: [{
                encapsulation: ViewEncapsulation.None,
                selector: 'metric',
                template: "<main>\r\n    <div [ngStyle]=\"valueStyle\">{{ value }}</div>\r\n    <div *ngIf=\"caption\" [ngStyle]=\"captionStyle\">{{ caption }}</div>\r\n</main>\r\n",
                styles: ["metric{bottom:0;display:table;height:100%;left:0;position:absolute;right:0;top:0;width:100%}metric>main{display:table-cell;overflow:hidden;text-align:center;vertical-align:middle}metric>main>div:first-of-type{font-size:24px;font-weight:700;text-overflow:ellipsis;white-space:nowrap}metric>main>div:nth-of-type(2){color:grey;font-size:14px;font-weight:700}"]
            },] }
];
MetricComponent.ctorParameters = () => [];
MetricComponent.propDecorators = {
    caption: [{ type: Input }],
    captionStyle: [{ type: Input, args: ['style-caption',] }],
    value: [{ type: Input }],
    valueStyle: [{ type: Input, args: ['style-value',] }]
};

class StatementComponent {
    constructor() { }
}
StatementComponent.decorators = [
    { type: Component, args: [{
                encapsulation: ViewEncapsulation.None,
                selector: 'statement',
                template: "<header *ngIf=\"title\" [ngStyle]=\"titleStyle\">{{ title }}</header>\r\n<main [ngStyle]=\"contentStyle\"><ng-content></ng-content></main>\r\n",
                styles: ["statement{display:block;line-height:1.5;padding:0}statement>header{font-size:18px;font-weight:700}statement>main{font-size:13px}"]
            },] }
];
StatementComponent.ctorParameters = () => [];
StatementComponent.propDecorators = {
    title: [{ type: Input }],
    contentStyle: [{ type: Input, args: ['style-content',] }],
    titleStyle: [{ type: Input, args: ['style-title',] }]
};

class TabComponent {
    constructor() { }
}
TabComponent.decorators = [
    { type: Component, args: [{
                encapsulation: ViewEncapsulation.None,
                selector: 'tab',
                template: "<ng-content></ng-content>\r\n",
                styles: ["tab{width:100%}"]
            },] }
];
TabComponent.ctorParameters = () => [];
TabComponent.propDecorators = {
    title: [{ type: Input }]
};

const hostStyles = {
    boxShadow: '1px 1px 2px black'
};
const headerStyles = {
    background: 'transparent',
    color: 'dimgray',
    display: 'flex',
    fontWeight: 'bold',
    left: 0,
    position: 'absolute',
    right: 0,
    textAlign: 'center',
    top: 0,
    whiteSpace: 'nowrap',
    zIndex: 1
};
const mainStyles = {
    background: 'white',
    bottom: 0,
    left: 0,
    overflow: 'auto',
    padding: '1em',
    position: 'absolute',
    right: 0
};
const tabActiveStyles = {
    background: '#e6e6e6',
    borderRight: '1px solid gray',
    color: '#340096',
    flexGrow: 1,
    fontSize: '16px',
    height: '32px',
    lineHeight: '32px',
    margin: 0,
    overflow: 'hidden',
    padding: '0 15px',
    position: 'relative',
    textOverflow: 'ellipsis',
    whiteSpace: 'nowrap'
};
const tabIdleStyles = {
    background: 'lightgray',
    borderRight: '1px solid gray',
    flexGrow: 1,
    height: '32px',
    lineHeight: '32px',
    margin: 0,
    overflow: 'hidden',
    padding: '0 15px',
    position: 'relative',
    textOverflow: 'ellipsis',
    whiteSpace: 'nowrap'
};
const tabHoverStyles = {
    background: '#e6e6e6',
    borderRight: '1px solid gray',
    cursor: 'pointer',
    flexGrow: 1,
    height: '32px',
    lineHeight: '32px',
    margin: 0,
    overflow: 'hidden',
    padding: '0 15px',
    position: 'relative',
    textOverflow: 'ellipsis',
    whiteSpace: 'nowrap'
};

class TileComponent {
    constructor(element, renderer) {
        this.element = element;
        this.renderer = renderer;
        this.hover = -1;
        this.marginActive = '';
        this.marginBreaks = [];
        this.paddingActive = '';
        this.paddingBreaks = [];
        this.positionStyles = {};
        this.tabTitles = [];
        this.boxShadowInput = '';
        this.fullScreenChange = new EventEmitter();
        this.tabChange = new EventEmitter();
        this.boxShadow = this.boxShadowInput || hostStyles.boxShadow;
    }
    onResize() {
        this.updateView();
    }
    ngOnInit() {
        const tileTab = localStorage.getItem('tile-tab');
        this.activeTab = (this.tabSave && tileTab) ? +tileTab : +this.tab || 0;
        this.setContainerPositions();
        this.setStyles();
        this.marginBreaks = this.setBreaks(this.marginValue);
        this.paddingBreaks = this.setBreaks(this.paddingValue);
        this.updateView();
        this.setTabState();
        this.updateActiveTab(this.activeTab);
    }
    ngOnChanges() {
        this.updateActiveTab(this.tab);
    }
    setContainerPositions() {
        this.positionStyles = {};
        if (!this.element.nativeElement.parentNode.attributes.getNamedItem('height')) {
            this.positionStyles = {
                position: 'relative',
                top: ''
            };
            this.renderer.setStyle(this.element.nativeElement, 'position', 'relative');
        }
    }
    setStyles() {
        this.styleMain = Object.assign(Object.assign(Object.assign({}, mainStyles), this.positionStyles), this.styleMain);
        this.styleHeader = Object.assign(Object.assign(Object.assign({}, headerStyles), this.positionStyles), this.styleHeader);
        this.styleTabActive = Object.assign(Object.assign({}, tabActiveStyles), this.styleTabActive);
        this.styleTabHover = Object.assign(Object.assign({}, tabHoverStyles), this.styleTabHover);
        this.styleTabIdle = Object.assign(Object.assign({}, tabIdleStyles), this.styleTabIdle);
    }
    setBreaks(value) {
        if (!value) {
            return [];
        }
        const pairs = value.split(' ');
        const breaks = pairs.map(pair => {
            if (pair.match(/:/)) {
                const pairSplit = pair.split(':');
                pairSplit[0] = isNaN(+pairSplit[0]) ? 0 : +pairSplit[0];
                return [pairSplit[0], pairSplit[1]];
            }
            return [0, pair];
        });
        return breaks.sort((a, b) => a[0] > b[0] ? 1 : -1);
    }
    updateView() {
        this.setMarginActive();
        this.setPaddingActive();
        this.setTileSize();
    }
    setMarginActive() {
        if (!this.marginValue) {
            return;
        }
        for (const pair of this.marginBreaks) {
            if (window.innerWidth < pair[0]) {
                break;
            }
            this.marginActive = pair[1];
        }
    }
    setPaddingActive() {
        if (!this.paddingValue) {
            return;
        }
        for (const pair of this.paddingBreaks) {
            if (window.innerWidth < pair[0]) {
                break;
            }
            this.paddingActive = pair[1];
        }
    }
    setTileSize() {
        this.marginActive = this.marginActive.replace('px', '') || '2';
        this.height = this.width = 'calc(100% - ' + (+this.marginActive * 2) + 'px)';
        this.margin = this.marginActive + 'px';
        if (this.paddingActive) {
            this.styleMain = Object.assign(Object.assign({}, this.styleMain), { padding: this.paddingActive });
        }
    }
    setTabState() {
        this.mainElement = this.element.nativeElement.children[0];
        if (this.mainElement) {
            const mainTabs = this.mainElement.children;
            const length = mainTabs.length;
            this.tabElements = [];
            if (mainTabs.length && mainTabs[0].nodeName === 'TAB') {
                for (let i = 0; i < length; i++) {
                    const title = mainTabs[0].attributes['title'];
                    if (title && title.value) {
                        this.tabTitles.push(title.value);
                    }
                    this.tabElements.push(mainTabs[0]);
                    this.renderer.removeChild(this.mainElement, mainTabs[0]);
                }
            }
        }
    }
    toggleFullScreen() {
        this.fullScreenActive = !this.fullScreenActive;
        this.fullScreenActive ? this.applyFullScreen() : this.cancelFullScreen();
        this.fullScreenChange.emit(this.fullScreenActive);
    }
    applyFullScreen() {
        // TODO: convert to class and properties
        [
            ['margin', '2px'],
            ['position', 'fixed'],
            ['top', '0'],
            ['left', '0'],
            ['right', '0'],
            ['bottom', '0'],
            ['width', 'auto'],
            ['height', 'auto'],
            ['zIndex', '2']
        ].forEach(item => this.renderer.setStyle(this.element.nativeElement, item[0], item[1]));
    }
    cancelFullScreen() {
        // TODO: change to class
        [
            ['margin', this.margin],
            ['position', 'absolute'],
            ['top', '0'],
            ['left', ''],
            ['right', ''],
            ['bottom', ''],
            ['width', this.width],
            ['height', this.height],
            ['zIndex', '']
        ].forEach(item => this.renderer.setStyle(this.element.nativeElement, item[0], item[1]));
    }
    updateActiveTab(index) {
        if (this.tab === undefined || !this.tabElements) {
            return;
        }
        if (this.activeTab !== index && this.tabElements[this.activeTab]) {
            this.renderer.removeChild(this.mainElement, this.tabElements[this.activeTab]);
        }
        if (this.tabElements[index]) {
            this.renderer.appendChild(this.mainElement, this.tabElements[index]);
        }
        this.activeTab = index;
        if (this.tabSave) {
            localStorage.setItem('tile-tab', this.activeTab.toString());
        }
        this.tabChange.emit(this.activeTab);
    }
}
TileComponent.decorators = [
    { type: Component, args: [{
                encapsulation: ViewEncapsulation.None,
                selector: 'tile',
                template: "<header *ngIf=\"fullScreen || title\" [ngStyle]=\"styleHeader\">\r\n    <span *ngIf=\"!tabTitles.length && title\"\r\n          [ngStyle]=\"styleTabActive\"\r\n          [title]=\"title\">\r\n        {{ title }}\r\n    </span>\r\n    <span *ngFor=\"let tab of tabTitles; let index = index;\"\r\n          [ngStyle]=\"hover === index && activeTab !== index ? styleTabHover : index === activeTab ? styleTabActive : styleTabIdle\"\r\n          [title]=\"tab\"\r\n          (click)=\"updateActiveTab(index)\"\r\n          (mouseout)=\"hover = -1\"\r\n          (mouseover)=\"hover = index\">\r\n        {{ tab }}\r\n    </span>\r\n    <span *ngIf=\"fullScreen\"\r\n          title=\"Expand/Collapse\"\r\n          [ngStyle]=\"hover === -2 ? styleTabHover : styleTabIdle\"\r\n          (click)=\"fullScreen && toggleFullScreen()\"\r\n          (mouseout)=\"hover = -1\"\r\n          (mouseover)=\"hover = -2\">\r\n        <div></div>\r\n        <div></div>\r\n    </span>\r\n</header>\r\n<main\r\n    [style.top]=\"fullScreen || title ? '32px' : '0'\"\r\n    [ngStyle]=\"styleMain\"\r\n>\r\n    <ng-content></ng-content>\r\n</main>\r\n",
                styles: ["tile{background:#fff;box-sizing:border-box;display:block;position:absolute;top:0}tile>header>span:last-of-type{border-right:none!important}tile>header>span>div{background:none;border:3px solid #696969;height:2px;position:absolute;width:2px}tile>header>span>div:first-of-type{border-bottom-color:transparent;border-left-color:transparent;right:10px;top:10px}tile>header>span>div:nth-of-type(2){border-right-color:transparent;border-top-color:transparent;right:13px;top:13px}"]
            },] }
];
TileComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 }
];
TileComponent.propDecorators = {
    boxShadowInput: [{ type: Input, args: ['box-shadow',] }],
    fullScreen: [{ type: Input, args: ['full-screen',] }],
    marginValue: [{ type: Input, args: ['margin',] }],
    paddingValue: [{ type: Input, args: ['padding',] }],
    styleHeader: [{ type: Input, args: ['style-header',] }],
    styleMain: [{ type: Input, args: ['style-main',] }],
    styleTabActive: [{ type: Input, args: ['style-tab-active',] }],
    styleTabIdle: [{ type: Input, args: ['style-tab-idle',] }],
    styleTabHover: [{ type: Input, args: ['style-tab-hover',] }],
    tab: [{ type: Input }],
    tabSave: [{ type: Input, args: ['tab-save',] }],
    title: [{ type: Input }],
    fullScreenChange: [{ type: Output, args: ['full-screen-change',] }],
    tabChange: [{ type: Output, args: ['tab-change',] }],
    boxShadow: [{ type: HostBinding, args: ['style.boxShadow',] }],
    height: [{ type: HostBinding, args: ['style.height',] }],
    margin: [{ type: HostBinding, args: ['style.margin',] }],
    width: [{ type: HostBinding, args: ['style.width',] }],
    onResize: [{ type: HostListener, args: ['window:resize', [],] }]
};

class NgMixUiModule {
}
NgMixUiModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    CellComponent,
                    DataTableComponent,
                    FlexButtonsComponent,
                    GridComponent,
                    MetricComponent,
                    StatementComponent,
                    TabComponent,
                    TileComponent
                ],
                imports: [
                    CommonModule
                ],
                exports: [
                    CellComponent,
                    DataTableComponent,
                    FlexButtonsComponent,
                    GridComponent,
                    MetricComponent,
                    StatementComponent,
                    TabComponent,
                    TileComponent
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { CellComponent, DataTableComponent, FlexButtonsComponent, GridComponent, MetricComponent, NgMixUiModule, StatementComponent, TabComponent, TileComponent, GridService as ɵa };
//# sourceMappingURL=ng-mix-ui.js.map
